.. _api-signup:

Signup
------

Here we must tell how to signup

.. _api-authentication:

Authentication
--------------

To get an access token you must authenticate by proving your user credentials.


.. _api-org:

Create an organiztion
---------------------

A user can create as many organization accounts as it want.


.. _api-membership:

Membership
----------

The owner of an organiozation is a member too.

.. _api-role:

Managing Roles
--------------


The roles are create per organization account.
